//********************************************************************************//
// Puara Gestures - Sensor fusion and gestural descriptors algorithms             //
// https://github.com/Puara/puara-gestures                                        //
// Société des Arts Technologiques (SAT) - https://sat.qc.ca                      //
// Input Devices and Music Interaction Laboratory (IDMIL) - https://www.idmil.org //
// Edu Meneses (2024) - https://www.edumeneses.com                                //
//********************************************************************************//

#pragma once

#include <IMU_Sensor_Fusion/imu_orientation.h>
#include <puara/descriptors/button.h>
#include <puara/descriptors/jab.h>
#include <puara/descriptors/roll.h>
#include <puara/descriptors/shake.h>
#include <puara/descriptors/tilt.h>
#include <puara/descriptors/simple_tilt_roll.h>
#include <puara/descriptors/touchArrayGestureDetector.h>
